@@ -1,3 +1,5 @@
+from typing import List
+
 from .common import NotionObject
 
 
@@ -6,8 +8,13 @@ class Pagination(NotionObject):
         super().__init__(None, kwargs=kwargs)
 
     @property
-    def results(self) -> list:
-        return self['results']
+    def results(self) -> List[NotionObject]:
+        from potion.utils.parser import parse
+        return [parse(i) for i in self['results']]
+
+    @property
+    def next_cursor(self):
+        return self['next_cursor']
 
     @property
     def has_more(self) -> bool:
