@@ -20,6 +20,17 @@ class Title(Property):
         return Title(None, rich_text=rich_text)
 
 
+class RichTextProp(Property):
+    property_name = 'rich_text'
+
+    def __init__(self, pname: str, rich_text: List[Union[Dict, RichText]]):
+        super().__init__(pname, args=rich_text)
+
+    @staticmethod
+    def PageTitle(rich_text: List[Union[Dict, RichText]]):
+        return Title(None, rich_text=rich_text)
+
+
 class Number(Property):
     def __init__(self, pname: str, number: float):
         super().__init__(pname, args=number)
@@ -42,19 +53,28 @@ class Select(Property):
         return self['color']
 
 
+class MultiSelectOption(Property):
+    def __init__(self, name=None):
+        super().__init__(None, kwargs=dict(name=name))
+
+
 class MultiSelect(Property):
     property_name = 'multi_select'
 
-    def __init__(self, pname, selects: Union[List[Select], _Null]):
+    def __init__(self, pname, selects: Union[List[MultiSelectOption], _Null]):
         if isinstance(selects, list):
             selects = [i._value for i in selects]
         super().__init__(pname, args=selects)
 
 
 class Date(Property):
-    def __init__(self, pname, start: datetime, end: datetime, time_zone: str):
-        kwargs = dict(start=start.isoformat(),
-                      end=end.isoformat(),
+    def __init__(self, pname, start: datetime = None, end: datetime = None, time_zone: str = None):
+        if start is not None:
+            start = start.isoformat()
+        if end is not None:
+            end = end.isoformat()
+        kwargs = dict(start=start,
+                      end=end,
                       time_zone=time_zone)
         super(Date, self).__init__(pname,
                                    kwargs=kwargs)
